@@ -17,6 +17,7 @@ import io
 from contextlib import redirect_stdout
 import argparse
 import inspect
+import re
 # import shutil
 from licface import CustomRichHelpFormatter
 # from textwrap import wrap
@@ -650,6 +651,12 @@ Examples:
             action='store_true',
             help='Show source code instead of help documentation'
         )
+
+        parser.add_argument(
+            '-i', '--interactive',
+            action='store_true',
+            help='Interactive mode'
+        )
         
         parser.add_argument(
             '-v', '--version',
@@ -673,43 +680,59 @@ Examples:
             return
         
         self.print_header()
-        
         module_name = parsed_args.module
-        show_source = parsed_args.source
-        
-        # Show module info
-        if RICH_AVAILABLE:
-            action = "source code" if show_source else "help"
-            module_info = Text()
-            module_info.append("🎯 Target: ", style="bold")
-            module_info.append(module_name, style="bold cyan")
-            module_info.append(f" ({action})", style="bold yellow")
-            self.console.print(Panel(module_info, style="blue"))
-        else:
-            action = "source code" if show_source else "help"
-            self.console.print(f"🎯 Target: {module_name} ({action})")
-        
-        start_time = time.time()
-        success = self.show_module_help(module_name, show_source)
-        end_time = time.time()
-        
-        # Show completion status
-        if RICH_AVAILABLE:
-            if success:
-                completion_text = Text()
-                completion_text.append("🎉 Operation completed in ", style="bold green")
-                completion_text.append(f"{end_time - start_time:.2f}s", style="bold yellow")
-                self.console.print(Panel(completion_text, style="green"))
+
+        while 1:
+            show_source = parsed_args.source
+            # Show module info
+            if RICH_AVAILABLE:
+                action = "source code" if show_source else "help"
+                module_info = Text()
+                module_info.append("🎯 Target: ", style="bold")
+                module_info.append(module_name, style="bold cyan")
+                module_info.append(f" ({action})", style="bold yellow")
+                self.console.print(Panel(module_info, style="blue"))
             else:
-                failure_text = Text()
-                failure_text.append("❌ Failed to complete operation", style="bold red")
-                failure_text.append("\n💡 Please check the module name and try again", style="yellow")
-                self.console.print(Panel(failure_text, style="red"))
-        else:
-            if success:
-                self.console.print(f"🎉 Operation completed in {end_time - start_time:.2f}s")
+                action = "source code" if show_source else "help"
+                self.console.print(f"🎯 Target: {module_name} ({action})")
+            
+            start_time = time.time()
+            success = self.show_module_help(module_name, show_source)
+            end_time = time.time()
+            
+            # Show completion status
+            if RICH_AVAILABLE:
+                if success:
+                    completion_text = Text()
+                    completion_text.append("🎉 Operation completed in ", style="bold green")
+                    completion_text.append(f"{end_time - start_time:.2f}s", style="bold yellow")
+                    self.console.print(Panel(completion_text, style="green"))
+                else:
+                    failure_text = Text()
+                    failure_text.append("❌ Failed to complete operation", style="bold red")
+                    failure_text.append("\n💡 Please check the module name and try again", style="yellow")
+                    self.console.print(Panel(failure_text, style="red"))
             else:
-                self.console.print("❌ Failed to complete operation")
+                if success:
+                    self.console.print(f"🎉 Operation completed in {end_time - start_time:.2f}s")
+                else:
+                    self.console.print("❌ Failed to complete operation")
+
+            if parsed_args.interactive:
+                self.console.print("[bold #00FFFF]q/quit/x/exit = exit/quit[/]") if RICH_AVAILABLE else print("q/quit/x/exit = exit/quit")
+                
+                q = input(": ")
+                if q:
+                    if q.lower().strip() in ['exit', 'quit', 'x', 'q']:
+                        sys.exit(0)
+                    elif "c " in q.lower().strip() or " c" in q.lower().strip():
+                        q = list(filter(None, list(filter(lambda k: k.strip() != 'c', re.split(" c|c | C|C ", q, re.I)))))
+                        q = q[0] if q else None
+                        os.system('cls') if 'win' in sys.platform.lower() else os.system('clear')
+                if q:
+                    module_name = q
+            else:
+                break
 
 def main():
     """Main function with Rich error handling"""
